===============================
bzoinq
===============================


.. image:: https://img.shields.io/pypi/v/bzoinq.svg
        :target: https://pypi.python.org/pypi/bzoinq

.. image:: https://img.shields.io/travis/lapisdecor/bzoinq.svg
        :target: https://travis-ci.org/lapisdecor/bzoinq

.. image:: https://readthedocs.org/projects/bzoinq/badge/?version=latest
        :target: https://bzoinq.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/lapisdecor/bzoinq/shield.svg
     :target: https://pyup.io/repos/github/lapisdecor/bzoinq/
     :alt: Updates


Simple calendar alarms

This project is currently in experimental development


* Free software: MIT license
* Documentation: https://bzoinq.readthedocs.io.


Features
--------

* Plays sounds on a given datetime

Credits
---------
Bzoinq is by Luis Louro and contributers are welcome
